from django.urls import path
# from .views import generate_agora_token
from .views import (
    CityListView, ConfirmKYCView, DeleteUserLanguageAPIView, DocumentUploadView, DocumentVerificationViewSet, GetProfileDeatils, HelpOptionsView, LanguageAPIView, ProfileMemberAPIView, ProfileViewSet, RoleListView, RoleSelectionView, IndustryListView, IndustrySelectionView,
    PrimaryIndustrySelectionView, SearchProfilesAPIView, SkillFilterAPIView, SkillListView, SkillSelectionView,
    PrimarySkillSelectionView,
    ExperienceViewSet, EducationViewSet, StateListView, StateShortNamesListView, StoreIndustryAPIView, StoreSkillAPIView, SyncMobileNumber, UnionAssociationViewSet, UpdateProfileStatusAPIView, UserLanguageAPIView
)

urlpatterns = [
    # Role endpoints
    path('profile/roles/', RoleListView.as_view({'get': 'list'}), name='role-list'),
    path('profile/join-as/', RoleSelectionView.as_view({'post': 'create'}), name='join-as'),
    path('profile/join-as/<int:user_id>/', RoleSelectionView.as_view({'patch': 'update'}), name='role-update'),

    # Industry endpoints
    path('profile/get-industries/', IndustryListView.as_view({'get': 'list'}), name='industry-list'),
    path('profile/select-industries/', IndustrySelectionView.as_view({'post': 'create'}), name='industry-select'),
    path('profile/select-industries/<int:user_id>/', IndustrySelectionView.as_view({'get': 'list_selected', 'patch': 'update'}), name='industry-edit'),  # Get, Update selected industries
    path('profile/select-industry/<int:industry_id>/', IndustrySelectionView.as_view({'delete': 'destroy'}), name='industry-delete'),
    path('profile/primary-industry/', PrimaryIndustrySelectionView.as_view({'post': 'create'}), name='primary-industry-select'),
    path('profile/primary-industry/<int:user_id>/', PrimaryIndustrySelectionView.as_view({'patch': 'update', 'delete': 'destroy'}), name='primary-industry-edit-delete'),
      
    # Skill endpoints
    path('profile/get-skills/', SkillListView.as_view({'get': 'list'}), name='skill-list'),
    path('profile/get_skills/', SkillFilterAPIView.as_view(), name='skill-list-post'),
    path('profile/select-skills/', SkillSelectionView.as_view({'post': 'create'}), name='skill-select'),
    path('profile/select-skills/<int:user_id>/', SkillSelectionView.as_view({'get': 'list_selected', 'patch': 'update'}), name='skill-edit'),  # Get, Update, Delete selected skills
    path('profile/select-skill/<int:skill_id>/', SkillSelectionView.as_view({'delete': 'destroy'}), name='skill-delete'),
    path('profile/primary-skill/', PrimarySkillSelectionView.as_view({'post': 'create'}), name='primary-skill-select'),
    path('profile/primary-skill/<int:user_id>/', PrimarySkillSelectionView.as_view({'patch': 'update', 'delete': 'destroy'}), name='primary-skill-edit-delete'),

    # Profile create, edit and detail
    path('profile/create/', ProfileViewSet.as_view({'post': 'create'}), name='profile-create'),
    path('profile/<int:user_id>/', ProfileViewSet.as_view({'get': 'retrieve', 'patch': 'partial_update'}), name='profile-detail-edit'),
    path('profile/<int:user_id>/profile-completion/', ProfileViewSet.as_view({'get': 'profile_completion'}), name='profile-completion-status'),
    
    #qr-code
    path('profile/<int:pk>/qr-code/', ProfileViewSet.as_view({'get': 'generate_qr_code'}), name='profile-qr-code'),

    # Experience endpoints
    path('profile/experience/', ExperienceViewSet.as_view({'post': 'create'}), name='experience-add'),
    path('profile/<int:user_id>/experience/', ExperienceViewSet.as_view({'get': 'list'}), name='user-experience'),
    path('profile/experience/<int:pk>/', ExperienceViewSet.as_view({'patch': 'update', 'delete': 'destroy'}), name='experience-detail'),

    # Education endpoints
    path('profile/education/', EducationViewSet.as_view({'post': 'create'}), name='education-add'),
    path('profile/<int:user_id>/education/', EducationViewSet.as_view({'get': 'list'}), name='user-education'),
    path('profile/education/<int:pk>/', EducationViewSet.as_view({'patch': 'update', 'delete': 'destroy'}), name='education-detail'),
    
    # Document verification 
    path('profile/docverifyaadhar/', DocumentVerificationViewSet.as_view({'post': 'verify_aadhar'}), name='doc-verify-aadhar'),
    path('profile/docverifypassport/', DocumentVerificationViewSet.as_view({'post': 'verify_passport'}), name='doc-verify-passport'),
    path('profile/docverifydl/', DocumentVerificationViewSet.as_view({'post': 'verify_dl'}), name='doc-verify-dl'),
    path('profile/docupload/', DocumentUploadView.as_view({'post': 'create'}), name='doc-upload'),
    
    # UnionAssociation endpoints
    path('profile/union-association/', UnionAssociationViewSet.as_view({'post': 'create'}), name='union-association-add'),
    path('profile/<int:user_id>/union-association/', UnionAssociationViewSet.as_view({'get': 'list'}), name='user-union-association'),
    path('profile/union-association/<int:pk>/', UnionAssociationViewSet.as_view({'patch': 'update', 'delete': 'destroy'}), name='union-association-detail'),
    
    path('profile/help/', HelpOptionsView.as_view(), name='help-options'),

    path('profile/details', GetProfileDeatils.as_view(), name='profile-details'),

    path('profile/confirmkyc/', ConfirmKYCView.as_view(), name='confirm_kyc'),

    path('profile/states/', StateListView.as_view(), name='states'),
    path('profile/states/cities/', CityListView.as_view(), name='state-cities'),
    path('profile/state_short_names/', StateShortNamesListView.as_view(), name='state_short_names_list'),
    path('profile/language/', LanguageAPIView.as_view(), name='languages'),
    path('profile/user_language/<int:user_id>/', UserLanguageAPIView.as_view(), name='user-language'),
    path('profile/delete_user_language/', DeleteUserLanguageAPIView.as_view(), name='Delete-language'),
    path('profile/user_language/', UserLanguageAPIView.as_view(), name='user-language-manage'),
    path('global/searchusers/', SearchProfilesAPIView.as_view(), name='search-profiles'),
    path('profile/status/', UpdateProfileStatusAPIView.as_view(), name='update-profile-status'),
    path('profile/members/', ProfileMemberAPIView.as_view(), name='profile-members'),
    path('profile/member/<int:user_id>/', ProfileMemberAPIView.as_view(), name='get-profile-member'),
    path('profile/members/<int:member_id>/', ProfileMemberAPIView.as_view(), name='delete-profile-members'),
    path('store_industry/', StoreIndustryAPIView.as_view(), name='store-industry'),
    path('store_skill/', StoreSkillAPIView.as_view(), name='store-skill'),
    path('sync/mobile-numbers/', SyncMobileNumber.as_view(), name='sync-mobile-number'),
]
